@@ -46,6 +46,8 @@ class Plugin(PluginAdapter):
         useSourceChannels = self.project.getConfig("useSourceChannels", False)
         if bool(useSourceChannels):
             sourceChannels = [c for c in sourceChannels if c["name"] in useSourceChannels]
+            if len(sourceChannels) == 0:
+                raise Exception("No sourceChannels left after filtering by useSourceChannels.")
 
         self.project.config["sourceChannelNames"] = [
             c["name"] for c in sourceChannels if "generated" not in c or not c["generated"]
